@@ -37,16 +37,16 @@
 StatisticsLegendWidget::StatisticsLegendWidget(QWidget * parent)
     : QWidget(parent)
 {
-    // QString tooltip;
-    // tooltip += "<table><tr><td>"+i18n("Progress gradients")+"</td><td bgcolor=\""
-    //         + gradeColor(KV_MAX_GRADE - 1).name()+"\"><nobr>    </nobr></td></tr>"
-    //         + "<tr><td>"+i18n("Early progress")+"</td><td bgcolor=\""
-    //         + preGradeColor().name()+"\"><nobr>    </nobr></td></tr>"
-    //         + "<tr><td>"+i18n("Not Practiced")+"</td><td bgcolor=\""
-    //         + unpracticedColor().name()+"\"><nobr>    </nobr></td></tr>"
-    //         + "<tr><td>"+i18n("Invalid Entries")+"</td><td bgcolor=\""
-    //         + invalidColor().name()+"\" width=\"15%\"><nobr>    </nobr></td></tr></table>";
-    // setToolTip(tooltip);
+    QString tooltip;
+    tooltip += "<table><tr><td>"+i18n("Progress gradients")+"</td><td bgcolor=\""
+            + gradeColor(KV_MAX_GRADE - 1).name()+"\"><nobr>    </nobr></td></tr>"
+            + "<tr><td>"+i18n("Early progress")+"</td><td bgcolor=\""
+            + preGradeColor().name()+"\"><nobr>    </nobr></td></tr>"
+            + "<tr><td>"+i18n("Not Practiced")+"</td><td bgcolor=\""
+            + unpracticedColor().name()+"\"><nobr>    </nobr></td></tr>"
+            + "<tr><td>"+i18n("Invalid Entries")+"</td><td bgcolor=\""
+            + invalidColor().name()+"\" width=\"15%\"><nobr>    </nobr></td></tr></table>";
+    setToolTip(tooltip);
 }
 
 
@@ -168,6 +168,11 @@ void StatisticsLegendWidget::paintEvent(QPaintEvent *)
     QString rightString = i18nc("adjective, The word has not even been practiced once by the user","Not practiced");
     QFontMetrics fontMetrics(painter.font());
 
+    I18N_NOOP("Initial phase");
+    I18N_NOOP("Long term phase");
+    I18N_NOOP("Invalid entry");
+    I18N_NOOP("Newly started");
+
     // Calculate the size and position of the rectangle that will contain the
     // string on the left side of the legend.
     QRect leftRect = fontMetrics.boundingRect(leftString);
